@@ -2,9 +2,9 @@ from fastapi import APIRouter, Request
 from fastapi.param_functions import Depends
 from jwcrypto import jwk
 
-from fief.dependencies.current_account import get_current_account
+from fief.dependencies.current_workspace import get_current_workspace
 from fief.dependencies.tenant import get_current_tenant
-from fief.models import Account, Tenant
+from fief.models import Tenant, Workspace
 from fief.schemas.well_known import OpenIDConfiguration
 from fief.settings import settings
 
@@ -14,7 +14,7 @@ router = APIRouter()
 @router.get("/openid-configuration", name="well_known:openid_configuration")
 async def get_openid_configuration(
     request: Request,
-    account: Account = Depends(get_current_account),
+    workspace: Workspace = Depends(get_current_workspace),
     tenant: Tenant = Depends(get_current_tenant),
 ):
     url_for_params = {}
@@ -25,7 +25,7 @@ async def get_openid_configuration(
         return request.url_for(name, **url_for_params)
 
     configuration = OpenIDConfiguration(
-        issuer=tenant.get_host(account.domain),
+        issuer=tenant.get_host(workspace.domain),
         authorization_endpoint=_url_for("auth:authorize"),
         token_endpoint=_url_for("auth:token"),
         userinfo_endpoint=_url_for("user:userinfo"),
